aboutsummaryrefslogtreecommitdiffstats
path: root/tools/libxl/libxlutil.h
diff options
context:
space:
mode:
authorIan Campbell <ian.campbell@citrix.com>2011-11-29 14:17:27 +0000
committerIan Campbell <ian.campbell@citrix.com>2011-11-29 14:17:27 +0000
commitd8dc5d8d75f9e913e7a0fdf5106dd7c654629ec4 (patch)
tree9d2a7f2441e1d4b3ba2e9e5f8bb4032efe111fe5 /tools/libxl/libxlutil.h
parent69941c321ee32c4ce177136f496ad2e8c455db62 (diff)
downloadxen-d8dc5d8d75f9e913e7a0fdf5106dd7c654629ec4.tar.gz
xen-d8dc5d8d75f9e913e7a0fdf5106dd7c654629ec4.tar.bz2
xen-d8dc5d8d75f9e913e7a0fdf5106dd7c654629ec4.zip
xlu: add "dont_warn" to xlu_cfg_*
I want it for get_long but we might as well have it everywhere. Signed-off-by: Ian Campbell <ian.campbell@citrix.com> Committed-by: Ian Jackson <ian.jackson.citrix.com> Acked-by: Ian Jackson <ian.jackson.citrix.com>
Diffstat (limited to 'tools/libxl/libxlutil.h')
-rw-r--r--tools/libxl/libxlutil.h12
1 files changed, 8 insertions, 4 deletions
diff --git a/tools/libxl/libxlutil.h b/tools/libxl/libxlutil.h
index 9d04b2d7bf..f0fbb757c2 100644
--- a/tools/libxl/libxlutil.h
+++ b/tools/libxl/libxlutil.h
@@ -41,13 +41,17 @@ void xlu_cfg_destroy(XLU_Config*);
* Return values are:
* 0 OK
* ESRCH not defined
* EINVAL value found but wrong format for request (prints warning)
* ERANGE value out of range (from strtol)
*/
-int xlu_cfg_get_string(const XLU_Config*, const char *n, const char **value_r);
-int xlu_cfg_replace_string(const XLU_Config *cfg, const char *n, char **value_r); /* free/strdup version */
-int xlu_cfg_get_long(const XLU_Config*, const char *n, long *value_r);
+int xlu_cfg_get_string(const XLU_Config*, const char *n, const char **value_r,
+ int dont_warn);
+/* free/strdup version */
+int xlu_cfg_replace_string(const XLU_Config *cfg, const char *n,
+ char **value_r, int dont_warn);
+int xlu_cfg_get_long(const XLU_Config*, const char *n, long *value_r,
+ int dont_warn);
int xlu_cfg_get_list(const XLU_Config*, const char *n,
XLU_ConfigList **list_r /* may be 0 */,
@@ -41,13 +41,17 @@ void xlu_cfg_destroy(XLU_Config*);
* 0 OK
* ESRCH not defined
- * EINVAL value found but wrong format for request (prints warning)
+ * EINVAL value found but wrong format for request (prints warning unless dont_warn=true)
* ERANGE value out of range (from strtol)
*/